@@ -1,6 +1,6 @@
 
 package Module::Build::Compat;
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 use strict;
 use File::Spec;
@@ -39,6 +39,7 @@ realclean :
 	rm -f $(THISFILE)
 .DEFAULT :
 	./Build $@
+.PHONY   : install
 EOF
 }
 
@@ -62,8 +63,6 @@ sub fake_prereqs {
 
 
 sub write_makefile {
-  # Note - this doesn't yet emulate the PREREQ_PM stuff.
-
   my ($pack, %in) = @_;
   $in{makefile} ||= 'Makefile';
   open  MAKE, "> $in{makefile}" or die "Cannot write $in{makefile}: $!";
@@ -82,29 +81,46 @@ Module::Build::Compat - Compatibility with ExtUtils::MakeMaker
 
 =head1 SYNOPSIS
 
-Here's a Makefile.PL that passes all functionality through to Module::Build
+Here's a Makefile.PL that passes all functionality through to
+C<Module::Build>:
 
   use Module::Build::Compat;
   Module::Build::Compat->run_build_pl(args => \@ARGV);
   Module::Build::Compat->write_makefile();
 
 
-Or, here's one that's more careful about sensing whether Module::Build
-is already installed:
+Or, here's one that's more careful about sensing whether
+C<Module::Build> is already installed, and will offer to install it if
+it's missing:
 
-  unless (eval { require Module::Build::Compat; 1 }) {
-    # Workaround with old CPAN.pm and CPANPLUS.pm
+  unless (eval "use Module::Build::Compat 0.02; 1" ) {
+    print "This module requires Module::Build to install itself.\n";
+    
     require ExtUtils::MakeMaker;
-    ExtUtils::MakeMaker::WriteMakefile(
-      PREREQ_PM => { 'Module::Build::Compat' => 0.01 }
-    );
-    warn "Warning: prerequisite Module::Build::Compat is not found.\n";
-    exit(0);
+    my $yn = ExtUtils::MakeMaker::prompt
+      ('  Install Module::Build from CPAN?', 'y');
+    
+    if ($yn =~ /^y/i) {
+      require Cwd;
+      require File::Spec;
+      require CPAN;
+      
+      # Save this 'cause CPAN will chdir all over the place.
+      my $cwd = Cwd::cwd();
+      my $makefile = File::Spec->rel2abs($0);
+      
+      CPAN::Shell->install('Module::Build::Compat');
+      
+      chdir $cwd or die "Cannot chdir() back to $cwd: $!";
+      exec $^X, $makefile, @ARGV;  # Redo now that we have Module::Build
+    } else {
+      warn " *** Cannot install without Module::Build.  Exiting ...\n";
+      exit 1;
+    }
   }
   Module::Build::Compat->run_build_pl(args => \@ARGV);
   Module::Build::Compat->write_makefile();
 
-
 =head1 DESCRIPTION
 
 This module helps you build a Makefile.PL that passes all
@@ -126,9 +142,7 @@ installed, and then the C<make> commands just pass through to the
 corresponding Module::Build actions.  That's what this module lets you
 do.
 
-A typical Makefile.PL is shown above in L<SYNOPSIS>.  See also
-L<FALLBACK> for some code that can help if the user doesn't have
-Module::Build installed yet.
+A typical Makefile.PL is shown above in L<SYNOPSIS>.
 
 So, some common scenarios are:
 
@@ -140,24 +154,24 @@ document explaining how to install the module.  In particular, explain
 that the user must install Module::Build before installing your
 module.  I prefer this method, mainly because I believe that the woes
 and hardships of doing this are far less significant than most people
-would have you believe.
+would have you believe.  It's also the simplest method, which is nice.
 
 =item 2.  Include a Build.PL script and a "regular" Makefile.PL.  This
-will make things easiest for your users, but hardest for you, as you
+may make things easiest for your users, but hardest for you, as you
 try to maintain two separate installation scripts.
 
 =item 3.  Include a Build.PL script and a "pass-through" Makefile.PL
 built using Module::Build::Compat.  This will mean that people can
-continue to use the "old" installation commands, but it's a little
-clumsy and there may be holes in the pass-through stuff I haven't
-thought of.  You may also include the code in L<FALLBACK> in your
-Makefile.PL.
+continue to use the "old" installation commands, and they may never
+notice that it's actually doing something else behind the scenes.
 
 =back
 
 =head1 METHODS
 
-=head2 run_build_pl()
+=over 4
+
+=item run_build_pl()
 
 This method runs the Build.PL script, passing it any arguments the
 user may have supplied to the C<perl Makefile.PL> command.  Because
@@ -168,19 +182,20 @@ C<run_build_pl()> accepts the following named parameters:
 
 =over 4
 
-=item * args
+=item args
 
 The C<args> parameter specifies the parameters that would usually
 appear on the command line of the C<perl Makefile.PL> command -
 typically you'll just pass a reference to C<@ARGV>.
 
-=item * script
+=item script
 
 This is the filename of the script to run - it defaults to C<Build.PL>.
 
 =back
 
-=head2 write_makefile()
+
+=item write_makefile()
 
 This method writes a 'dummy' Makefile that will pass all commands
 through to the corresponding Module::Build actions.
@@ -189,49 +204,13 @@ C<write_makefile()> accepts the following named parameters:
 
 =over 4
 
-=item * makefile
+=item makefile
 
 The name of the file to write - defaults to the string C<Makefile>.
 
 =back
 
-
-
-=head1 FALLBACK
-
-You may be wondering what happens when the user doesn't already have
-Module::Build installed - in this case, the installation process is
-going to fail until they install it.  Fortunately, if the user is
-using CPAN.pm, we can exploit its prerequisite mechanism in order to
-get Module::Build installed.  Amazingly, CPAN.pm actually reads the
-PREREQ_PM information from a comment in the generated Makefile.
-Therefore, the following Makefile.PL may be useful (make certain you
-preserve tabs!):
-
- -------------------------------------------------------------
- unless ( eval {require Module::Build::Compat} ) {
-   # The user doesn't have Module::Build installed.  Put it as a 
-   # prereq in the Makefile, so that CPAN.pm will install it.
- 
-   open MAKE, ">Makefile" or die "Cannot write Makefile: $!";
-   print MAKE <<EOF;
- #	PREREQ_PM => { Module::Build=>q[0.05] }
- all : .DEFAULT
- 
- .DEFAULT :
- 	\@echo "  This module requires Module::Build to test and install."
- 	\@echo "  Please install Module::Build first, then re-run 'perl Makefile.PL'."
- EOF
-   close MAKE;
-   exit 0;
- }
- 
- # The user *does* have Module::Build installed.  Run Build.PL and make a pass-through Makefile.
- Module::Build::Compat->run_build_pl(args => \@ARGV);
- Module::Build::Compat->write_makefile;
- -------------------------------------------------------------
-
-
+=back
 
 =head1 AUTHOR
 
